<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'type_birthday' => 'Ευχόμαστε ευτυχισμένα γενέθλια στο άτομο',
    'type_phone_call' => 'Κλήση',
    'type_lunch' => 'Γεύμα με',
    'type_hangout' => 'Βρέθηκα με',
    'type_email' => 'Email',
    'type_birthday_kid' => 'Ευχηθείτε χαρούμενα γενέθλια στο παιδί του',
];
